
# 🔥📊📣 VizPool 📣📊🔥[![Downloads](https://pepy.tech/badge/vizpool)](https://pepy.tech/project/vizpool) [!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/hassi34)

VizPool is a high level python API for data visualization.It provides low-code support for static and interactive visuals.

## Overview
### 🔗 Project Link
Check out the Pypi Package [here](https://pypi.org/project/vizpool/)
### Installation
Install via Pip!
```bash
pip install vizpool
```

### Usage
import the components and use it like any other python package
* Static Visuals
```bash
from vizpool import static
```
* Interactive Visuals
```bash
from vizpool import interactive
```
# Contributing
Yes, Please!  I believe that there is alot of oportunity to make even the most complex visuals available for data comunity, so lets make it more efficient, let go with low-code!!

Follow the instructions on the `vizpoolQuickStart` [example file](https://github.com/Hassi34/vizpool/blob/master/vizpoolQuickStart.ipynb) to get up and running, or follow along below!

### Quickstart

* Ensure you have [Python 3.7+](https://www.python.org/downloads/) installed.

* Create a new Python conda environment for the vizpool:

```

$ conda create -n venv  # create venv
$ conda activate venv  # activate venv
$ pip install vizpool # install vizpool
```

* Create a new Python virtual environment with pip for the vizpool:
```

$ python3 -m venv venv  # create venv
$ . venv/bin/activate   # activate venv
$ pip install streamlit # install vizpool
```

